guix_mirror_bot pushed a commit to branch c++-team
in repository guix.

commit bab6bd48f8415a93ef1c2db7738f654d07264af2
Author: Greg Hogan <[email protected]>
AuthorDate: Wed May 7 19:32:39 2025 +0000

    gnu: Restore gnu-build-system phases.
    
    * gnu/packages/bioinformatics.scm (bandage),
    * gnu/packages/education.scm (openboard),
    * gnu/packages/emulators.scm (qtmips),
    * gnu/packages/games.scm (chessx),
    * gnu/packages/kde-systemtools.scm (spectacle-ocr-screenshot),
    * gnu/packages/qt.scm (pyotherside, qtwidgetanimationframework)
    <#:phases>: Restore build phase.
    
    * gnu/packages/admin.scm (wpa-supplicant-gui),
    * gnu/packages/finance.scm (kitsas)
    [arguments]<#:tests?>: Disable.
    <#:phases>: Restore build phase.
    
    * gnu/packages/engineering.scm (librecad)
    [arguments]<#:test-target>: Delete.
    <#:phases>: Restore build and check phases.
    
    * gnu/packages/music.scm (samplebrain)
    <#:phases>: Restore build, check, and install phases.
    
    * gnu/packages/password-utils.scm (qtpass)
    [arguments]<#:test-target>: Delete.
    <#:phases>: Restore build, check, and install phases.
    
    * gnu/packages/ebook.scm (inkbox),
    * gnu/packages/engineering.scm (qelectrotech),
    * gnu/packages/games.scm (doom-runner, moonlight-qt, pokerth,
    qcheckers),
    * gnu/packages/gps.scm (gpxsee),
    * gnu/packages/hardware.scm (openrgb),
    * gnu/packages/image-viewers.scm (qview),
    * gnu/packages/pdf.scm (qpdfview),
    * gnu/packages/qt.scm (signond),
    * gnu/packages/radio.scm (dream)
    <#:phases>: Restore build and install phases.
    
    * gnu/packages/disk.scm (qdirstat),
    * gnu/packages/pdf.scm (sioyek),
    * gnu/packages/qt.scm (signon-plugin-oauth2),
    * gnu/packages/radio.scm (qsstv, wfview),
    * gnu/packages/security-token.scm (yubikey-manager-qt),
    * gnu/packages/tex.scm (texmaker),
    * gnu/packages/video.scm (smplayer)
    [arguments]<#:tests?>: Disable.
    <#:phases>: Restore build and install phases.
    
    * gnu/packages/audio.scm (supercollider)
    <#:phases>: Restore install phase.
    
    * gnu/packages/web.scm (libzim): Update to 9.3.0.
    (kiwix-lib): Update to 14.0.0.
    (kiwix-desktop): Update to 2.4.1.
    [source](patches): Delete.
    [arguments]<#:test-target>: Delete.
    [arguments]<#:tests?>: Disable.
    <#:phases>: Restore build and install phases.
    (kiwix-tools): Update to 3.7.0.
    
    * gnu/packages/patches/kiwix-desktop-newer-libkiwix.patch: Delete.
    * gnu/local.mk: Update accordingly.
    
    Change-Id: Ia5162ec190fc21334bbc516dcc01056d599f2891
---
 gnu/local.mk                                       |  1 -
 gnu/packages/admin.scm                             |  6 +-
 gnu/packages/audio.scm                             |  4 +
 gnu/packages/bioinformatics.scm                    |  4 +
 gnu/packages/disk.scm                              |  6 ++
 gnu/packages/ebook.scm                             |  7 +-
 gnu/packages/education.scm                         |  4 +
 gnu/packages/emulators.scm                         | 71 +++++++++--------
 gnu/packages/engineering.scm                       | 29 ++++---
 gnu/packages/finance.scm                           |  5 +-
 gnu/packages/games.scm                             | 85 +++++++++++++--------
 gnu/packages/gps.scm                               |  7 +-
 gnu/packages/hardware.scm                          |  7 +-
 gnu/packages/image-viewers.scm                     |  7 +-
 gnu/packages/kde-systemtools.scm                   |  4 +
 gnu/packages/music.scm                             |  8 +-
 gnu/packages/password-utils.scm                    |  7 +-
 .../patches/kiwix-desktop-newer-libkiwix.patch     | 40 ----------
 gnu/packages/pdf.scm                               | 16 +++-
 gnu/packages/qt.scm                                | 22 +++++-
 gnu/packages/radio.scm                             | 89 +++++++++++++---------
 gnu/packages/security-token.scm                    |  5 ++
 gnu/packages/tex.scm                               | 32 ++++----
 gnu/packages/video.scm                             |  5 ++
 gnu/packages/web.scm                               | 39 +++++-----
 25 files changed, 315 insertions(+), 195 deletions(-)

diff --git a/gnu/local.mk b/gnu/local.mk
index 89feb9a7fa..baa57a31f0 100644
--- a/gnu/local.mk
+++ b/gnu/local.mk
@@ -1711,7 +1711,6 @@ dist_patch_DATA =                                         
\
   %D%/packages/patches/kio-search-smbd-on-PATH.patch           \
   %D%/packages/patches/kismet-unbundle-boost.patch             \
   %D%/packages/patches/kitty-fix-wayland-protocols.patch       \
-  %D%/packages/patches/kiwix-desktop-newer-libkiwix.patch      \
   %D%/packages/patches/kmod-module-directory.patch             \
   %D%/packages/patches/kmscon-runtime-keymap-switch.patch      \
   %D%/packages/patches/knot-remove-runtime-deps.patch          \
diff --git a/gnu/packages/admin.scm b/gnu/packages/admin.scm
index 0c0139e10f..d6a8c6fc71 100644
--- a/gnu/packages/admin.scm
+++ b/gnu/packages/admin.scm
@@ -2686,16 +2686,20 @@ command.")
     (build-system qt-build-system)
     (arguments
      (list
+      #:tests? #f ; no tests
       ;; Make sure the (rarely updated) package 'imagemagick/stable'
       ;; does not end up in the closure.
       #:disallowed-references (list imagemagick/stable)
-      #:test-target "check"
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (add-after 'unpack 'chdir
             (lambda _ (chdir "wpa_supplicant/wpa_gui-qt4")))
           (replace 'configure
             (lambda _ (invoke "qmake" "wpa_gui.pro")))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
           (add-after 'build 'build-icons
             (lambda _
               ;; Inkscape complains (but works) without a writable $HOME.
diff --git a/gnu/packages/audio.scm b/gnu/packages/audio.scm
index a140201418..70f7f103e9 100644
--- a/gnu/packages/audio.scm
+++ b/gnu/packages/audio.scm
@@ -4216,6 +4216,9 @@ link REQUIRED)"))))))
               "-DFORTIFY=ON"
               "-DLIBSCSYNTH=ON"
               "-DSC_EL=OFF")      ;scel is packaged individually as emacs-scel
+      #:modules '((guix build cmake-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           ;; HOME must be defined otherwise supercollider throws a "ERROR:
@@ -4243,6 +4246,7 @@ link REQUIRED)"))))))
             (lambda _
               (system "Xvfb &")
               (setenv "DISPLAY" ":0")))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install))
           (add-before 'install 'install-ide
             (lambda _
               (let* ((ide #$output:ide)
diff --git a/gnu/packages/bioinformatics.scm b/gnu/packages/bioinformatics.scm
index 184e43ffcb..0103bdc788 100644
--- a/gnu/packages/bioinformatics.scm
+++ b/gnu/packages/bioinformatics.scm
@@ -18842,6 +18842,9 @@ Thus the per-base error rate is similar to the raw 
input reads.")
     (build-system qt-build-system)
     (arguments
      (list
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       ;; TODO: Once <https://issues.guix.gnu.org/47475> is fixed,
       ;; consider uncommenting the following:
       ;;
@@ -18862,6 +18865,7 @@ Thus the per-base error rate is similar to the raw 
input reads.")
                 (with-directory-excursion "tests"
                   (setenv "XDG_RUNTIME_DIR" (getcwd))
                   (invoke "./bandage_command_line_tests.sh")))))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
           (replace 'install
             (lambda _
               (install-file "Bandage" (string-append #$output "/bin")))))))
diff --git a/gnu/packages/disk.scm b/gnu/packages/disk.scm
index a4df50bd4b..87ce589e1a 100644
--- a/gnu/packages/disk.scm
+++ b/gnu/packages/disk.scm
@@ -1805,11 +1805,17 @@ wrapper for disk usage querying and visualisation.")
     (build-system qt-build-system)
     (arguments
      (list
+      #:tests? #f
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (replace 'configure
             (lambda _
               (system* "qmake" (string-append "INSTALL_PREFIX=" #$output))))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install))
           (add-after 'install 'wrap
             (lambda _
               (wrap-program (string-append #$output
diff --git a/gnu/packages/ebook.scm b/gnu/packages/ebook.scm
index d772d5244c..8deb82aa40 100644
--- a/gnu/packages/ebook.scm
+++ b/gnu/packages/ebook.scm
@@ -405,6 +405,9 @@ accessing and converting various ebook file formats.")
       #:tests? #f                      ; no test suite
       #:make-flags
       #~(list (string-append "PREFIX=" #$output))
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
          (add-after 'unpack 'prefix-opt
@@ -414,7 +417,9 @@ accessing and converting various ebook file formats.")
                 #$output))))
          (replace 'configure
            (lambda* (#:key make-flags #:allow-other-keys)
-             (apply invoke (cons "qmake" make-flags)))))))
+             (apply invoke (cons "qmake" make-flags))))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (native-inputs
      (list qtbase-5))
     (synopsis "EBook reader")
diff --git a/gnu/packages/education.scm b/gnu/packages/education.scm
index 5e0d467cc0..1f022b06b4 100644
--- a/gnu/packages/education.scm
+++ b/gnu/packages/education.scm
@@ -514,6 +514,9 @@ specialized device.")
     (arguments
      (list
       #:tests? #f                       ;no tests
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (add-after 'unpack 'set-initial-values
@@ -542,6 +545,7 @@ specialized device.")
           (replace 'configure
             (lambda _
               (invoke "qmake" "OpenBoard.pro")))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
           (replace 'install
             (lambda* (#:key inputs #:allow-other-keys)
               (let* ((share (string-append #$output "/share"))
diff --git a/gnu/packages/engineering.scm b/gnu/packages/engineering.scm
index f5c9035f0b..d30471da7a 100644
--- a/gnu/packages/engineering.scm
+++ b/gnu/packages/engineering.scm
@@ -309,21 +309,25 @@ their devices.")
     (build-system qt-build-system)
     (arguments
      (list
-      #:test-target "check"
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (replace 'configure
             (lambda _
               (system* "qmake" (string-append "BOOST_DIR="
                                               #$(this-package-input 
"boost")))))
-         (replace 'install
-           (lambda* (#:key outputs #:allow-other-keys)
-             (let ((bin   (string-append #$output "/bin"))
-                   (share (string-append #$output "/share/librecad")))
-               (mkdir-p bin)
-               (install-file "unix/librecad" bin)
-               (mkdir-p share)
-               (copy-recursively "unix/resources" share)))))))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'check (assoc-ref gnu:%standard-phases 'check))
+          (replace 'install
+            (lambda* (#:key outputs #:allow-other-keys)
+              (let ((bin   (string-append #$output "/bin"))
+                    (share (string-append #$output "/share/librecad")))
+                (mkdir-p bin)
+                (install-file "unix/librecad" bin)
+                (mkdir-p share)
+                (copy-recursively "unix/resources" share)))))))
     (inputs
      (list bash-minimal boost muparser freetype qtbase-5 qtsvg-5))
     (native-inputs
@@ -959,6 +963,9 @@ required for Fritzing app.")
      ;; XXX: tests are built for the CMake build option but it seems to be
      ;; broken in 0.8.0.
      (list #:tests? #f
+           #:modules '((guix build qt-build-system)
+                       ((guix build gnu-build-system) #:prefix gnu:)
+                       (guix build utils))
            #:phases
            #~(modify-phases %standard-phases
                (replace 'configure
@@ -966,7 +973,9 @@ required for Fritzing app.")
                    ;; Patch hardcoded path before running qmake.
                    (substitute* "qelectrotech.pro"
                      (("\\/usr\\/local") #$output))
-                   (invoke "qmake"))))))
+                   (invoke "qmake")))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (native-inputs
      (list pkg-config qttools-5))
     (inputs
diff --git a/gnu/packages/finance.scm b/gnu/packages/finance.scm
index c8c0465b4a..7c8034729b 100644
--- a/gnu/packages/finance.scm
+++ b/gnu/packages/finance.scm
@@ -1359,8 +1359,10 @@ agent.")
     (inputs (list libzip qtsvg qtwebengine qt5compat))
     (arguments
      (list #:tests? #f           ; tests do not even build with Qt6 anymore
-           #:test-target "check"
            #:qtbase qtbase       ; use Qt6
+           #:modules '((guix build qt-build-system)
+                       ((guix build gnu-build-system) #:prefix gnu:)
+                       (guix build utils))
            #:phases
            #~(modify-phases %standard-phases
                (replace 'configure
@@ -1372,6 +1374,7 @@ agent.")
                    (substitute* "kitsasproject.pro"
                      ((" *(unittest|testit).*") "")
                      (("\\\\") ""))))
+               (replace 'build (assoc-ref gnu:%standard-phases 'build))
                (replace 'install
                  (lambda* _
                    (install-file "kitsas/kitsas"
diff --git a/gnu/packages/games.scm b/gnu/packages/games.scm
index c9a1549b68..2fb087e127 100644
--- a/gnu/packages/games.scm
+++ b/gnu/packages/games.scm
@@ -1553,6 +1553,9 @@ practise.")
     (arguments
      (list
       #:tests? #f                       ;no tests
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (replace 'configure
@@ -1562,6 +1565,8 @@ practise.")
                  #$output))
               (invoke "qmake" "DoomRunner.pro" "-spec" "linux-g++"
                       "\"CONFIG+=release\"")))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install))
           (add-after 'install 'install-xdg
             (lambda _
               (with-directory-excursion "Install/XDG"
@@ -7106,6 +7111,9 @@ colors, pictures, and sounds.")
     (arguments
      (list
       #:tests? #f ;no test suite
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (replace 'configure
@@ -7121,7 +7129,9 @@ colors, pictures, and sounds.")
                 (("    h264bitstream.*\n") "")
                 (("    app \\\\") "    app")
                 (("app.depends") "INCLUDEPATH +="))
-              (invoke "qmake" (string-append "PREFIX=" #$output)))))))
+              (invoke "qmake" (string-append "PREFIX=" #$output))))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (native-inputs (list pkg-config qttools-5))
     (inputs (list ffmpeg
                   h264bitstream
@@ -11692,12 +11702,17 @@ can be downloaded from 
@url{https://zero.sjeng.org/best-network}.";)
     (arguments
      (list
       #:tests? #f
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (replace 'configure
             (lambda _
               (invoke "qmake"
-                      (string-append "PREFIX=" #$output)))))))
+                      (string-append "PREFIX=" #$output))))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (inputs (list qtbase-5 qtsvg-5))
     (home-page "https://portnov.github.io/qcheckers/";)
     (synopsis "Qt-based checkers boardgame")
@@ -11884,35 +11899,36 @@ and chess engines.")
     (inputs
      (list qtbase-5 qtmultimedia-5 qtspeech-5 qtsvg-5 zlib))
     (arguments
-     `(#:tests? #f
-       #:phases
-       (modify-phases %standard-phases
-         (add-after 'unpack 'fix-paths
-           (lambda* (#:key inputs #:allow-other-keys)
-             (substitute* "chessx.pro"
-               (("\\$\\$\\[QT_INSTALL_BINS\\]/lrelease")
-                (search-input-file inputs "/bin/lrelease")))))
-         (add-after 'fix-paths 'make-qt-deterministic
-           (lambda _
-             (setenv "QT_RCC_SOURCE_DATE_OVERRIDE" "1")
-             #t))
-         (add-after 'make-qt-deterministic 'disable-versioncheck
-           (lambda _
-             (substitute* "src/database/settings.cpp"
-               (("\"/General/onlineVersionCheck\", true")
-                "\"/General/onlineVersionCheck\", false"))
-             #t))
-         (replace 'configure
-           (lambda _
-             (invoke "qmake")
-             #t))
-         (replace 'install
-           (lambda* (#:key outputs #:allow-other-keys)
-             (let ((out (assoc-ref outputs "out")))
-               (install-file "release/chessx" (string-append out "/bin"))
-               (install-file "unix/chessx.desktop"
-                             (string-append out "/share/applications")))
-             #t)))))
+     (list
+      #:tests? #f
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-after 'unpack 'fix-paths
+            (lambda* (#:key inputs #:allow-other-keys)
+              (substitute* "chessx.pro"
+                (("\\$\\$\\[QT_INSTALL_BINS\\]/lrelease")
+                 (search-input-file inputs "/bin/lrelease")))))
+          (add-after 'fix-paths 'make-qt-deterministic
+            (lambda _
+              (setenv "QT_RCC_SOURCE_DATE_OVERRIDE" "1")))
+          (add-after 'make-qt-deterministic 'disable-versioncheck
+            (lambda _
+              (substitute* "src/database/settings.cpp"
+                (("\"/General/onlineVersionCheck\", true")
+                 "\"/General/onlineVersionCheck\", false"))))
+          (replace 'configure
+            (lambda _
+              (invoke "qmake")))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install
+            (lambda* (#:key outputs #:allow-other-keys)
+              (let ((out (assoc-ref outputs "out")))
+                (install-file "release/chessx" (string-append out "/bin"))
+                (install-file "unix/chessx.desktop"
+                              (string-append out "/share/applications"))))))))
     (synopsis "Chess game database")
     (description
      "ChessX is a chess database.  With ChessX you can operate on your
@@ -12286,6 +12302,9 @@ game.")  ;thanks to Debian for description
     (arguments
      (list
       #:tests? #f                       ; No test suite
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (add-after 'unpack 'fix-paths
@@ -12308,7 +12327,9 @@ game.")  ;thanks to Debian for description
           (replace 'configure
             (lambda _
               (invoke "qmake" "pokerth.pro" "CONFIG+=client"
-                      (string-append "PREFIX=" #$output)))))))
+                      (string-append "PREFIX=" #$output))))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (home-page "https://www.pokerth.net";)
     (synopsis "Texas holdem poker game")
     (description
diff --git a/gnu/packages/gps.scm b/gnu/packages/gps.scm
index aefb993f79..8ee1515d6b 100644
--- a/gnu/packages/gps.scm
+++ b/gnu/packages/gps.scm
@@ -220,6 +220,9 @@ coordinates as well as partial support for adjustments in 
global coordinate syst
      (list
       #:qtbase qtbase
       #:tests? #f                     ; no tests
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases #~(modify-phases %standard-phases
                    (replace 'configure
                      ;; Use lrelease to convert TS translation files into QM 
files.
@@ -227,7 +230,9 @@ coordinates as well as partial support for adjustments in 
global coordinate syst
                        (apply invoke "lrelease"
                               (find-files "lang" "\\.ts"))
                        (invoke "qmake"
-                               (string-append "PREFIX=" #$output)))))))
+                               (string-append "PREFIX=" #$output))))
+                   (replace 'build (assoc-ref gnu:%standard-phases 'build))
+                   (replace 'install (assoc-ref gnu:%standard-phases 
'install)))))
     (inputs (list libxkbcommon qtbase qtpositioning qtserialport qtsvg))
     (native-inputs (list qttools))
     (home-page "https://www.gpxsee.org";)
diff --git a/gnu/packages/hardware.scm b/gnu/packages/hardware.scm
index ff063bd368..961d524b4b 100644
--- a/gnu/packages/hardware.scm
+++ b/gnu/packages/hardware.scm
@@ -1149,6 +1149,9 @@ technology, such as head mounted displays with built in 
head tracking.")
        #:tests? #f ; doesn't have tests
        #:make-flags
        #~(list (string-append "INSTALL_ROOT=" #$output ))
+       #:modules '((guix build qt-build-system)
+                   ((guix build gnu-build-system) #:prefix gnu:)
+                   (guix build utils))
        #:phases
        #~(modify-phases %standard-phases
            (add-after 'unpack 'unbundle
@@ -1167,7 +1170,9 @@ technology, such as head mounted displays with built in 
head tracking.")
                                                "/bin/chmod")))))
            ;; Call qmake instead of configure to create a Makefile.
            (replace 'configure
-             (lambda _ (invoke "qmake" "PREFIX=/" "OpenRGB.pro"))))))
+             (lambda _ (invoke "qmake" "PREFIX=/" "OpenRGB.pro")))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (inputs
      (list coreutils
            hidapi
diff --git a/gnu/packages/image-viewers.scm b/gnu/packages/image-viewers.scm
index 58c0158609..23903c67a4 100644
--- a/gnu/packages/image-viewers.scm
+++ b/gnu/packages/image-viewers.scm
@@ -822,6 +822,9 @@ Poppler-Qt5 binding, PDF documents.")
      (list
       #:qtbase qtbase
       #:tests? #f ; test code doesn't compile
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (replace 'configure
@@ -836,7 +839,9 @@ Poppler-Qt5 binding, PDF documents.")
             (lambda _
               (substitute* "src/qvaboutdialog.cpp"
                 (("qvApp->checkUpdates\\(\\);") "")
-                (("updateText\\(\\);") "")))))))
+                (("updateText\\(\\);") ""))))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (native-inputs
      (list qttools))
     (inputs
diff --git a/gnu/packages/kde-systemtools.scm b/gnu/packages/kde-systemtools.scm
index 8f15a35cbb..f69e618707 100644
--- a/gnu/packages/kde-systemtools.scm
+++ b/gnu/packages/kde-systemtools.scm
@@ -400,11 +400,15 @@ This package is part of the KDE administration module.")
     (arguments
      (list #:qtbase qtbase
            #:tests? #f ;no tests
+           #:modules '((guix build qt-build-system)
+                       ((guix build gnu-build-system) #:prefix gnu:)
+                       (guix build utils))
            #:phases
            #~(modify-phases %standard-phases
                (replace 'configure
                  (lambda _
                    (invoke "qmake" (string-append "PREFIX=" #$output))))
+               (replace 'build (assoc-ref gnu:%standard-phases 'build))
                (replace 'install
                  (lambda _
                    (install-file "spectacle-ocr-screenshot"
diff --git a/gnu/packages/music.scm b/gnu/packages/music.scm
index e8b8d0dff0..2ca6f3e3a8 100644
--- a/gnu/packages/music.scm
+++ b/gnu/packages/music.scm
@@ -8247,13 +8247,19 @@ Renoise, VCV Rack, or SuperCollider.")
     (build-system qt-build-system)
     (arguments
      (list #:tests? #f ;no tests
+           #:modules '((guix build qt-build-system)
+                       ((guix build gnu-build-system) #:prefix gnu:)
+                       (guix build utils))
            #:phases #~(modify-phases %standard-phases
                         (replace 'configure
                           (lambda _
                             (substitute* "samplebrain.pro"
                               (("\\/usr")
                                #$output))
-                            (invoke "qmake"))))))
+                            (invoke "qmake")))
+                        (replace 'build (assoc-ref gnu:%standard-phases 
'build))
+                        (replace 'check (assoc-ref gnu:%standard-phases 
'check))
+                        (replace 'install (assoc-ref gnu:%standard-phases 
'install)))))
     (inputs (list fftw liblo libsndfile portaudio))
     (home-page "https://thentrythis.org/projects/samplebrain/";)
     (synopsis "Sample mashing synthesizer designed by Aphex Twin")
diff --git a/gnu/packages/password-utils.scm b/gnu/packages/password-utils.scm
index 7e5d6acbb7..051dc6a9ac 100644
--- a/gnu/packages/password-utils.scm
+++ b/gnu/packages/password-utils.scm
@@ -1079,7 +1079,9 @@ key URIs using the standard otpauth:// scheme.")
     (build-system qt-build-system)
     (arguments
      (list
-      #:test-target "check"
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (replace 'configure
@@ -1088,9 +1090,12 @@ key URIs using the standard otpauth:// scheme.")
                       "QMAKE_LRELEASE=lrelease"
                       "QMAKE_LUPDATE=lupdate"
                       (string-append "PREFIX=" #$output))))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'check (assoc-ref gnu:%standard-phases 'check))
           (add-before 'check 'pre-check
             ;; Fontconfig needs a writable cache.
             (lambda _ (setenv "HOME" "/tmp")))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install))
           (add-after 'install 'install-auxilliary
             ;; Install man-page, icon and .desktop file.
             (lambda _
diff --git a/gnu/packages/patches/kiwix-desktop-newer-libkiwix.patch 
b/gnu/packages/patches/kiwix-desktop-newer-libkiwix.patch
deleted file mode 100644
index a5bee60ac2..0000000000
--- a/gnu/packages/patches/kiwix-desktop-newer-libkiwix.patch
+++ /dev/null
@@ -1,40 +0,0 @@
-Description: Fix building kiwix-desktop with libkiwix-12.1.0
-Bug: https://github.com/kiwix/kiwix-desktop/issues/964
-Origin: 
https://github.com/kiwix/kiwix-desktop/commit/1b322d8f01c787846546a6473f153cf1daa41e65
-Applied-Upstream: 
https://github.com/kiwix/kiwix-desktop/commit/1b322d8f01c787846546a6473f153cf1daa41e65
----
-From 1b322d8f01c787846546a6473f153cf1daa41e65 Mon Sep 17 00:00:00 2001
-From: Matthieu Gautier <[email protected]>
-Date: Thu, 9 Feb 2023 09:47:47 +0100
-Subject: [PATCH] With last version of libkiwix, Downloader now return
- shared_ptr<Download>.
-
----
- src/contentmanager.cpp | 4 ++--
- 1 file changed, 2 insertions(+), 2 deletions(-)
-
-diff --git a/src/contentmanager.cpp b/src/contentmanager.cpp
-index c2f4ff9..d4db50a 100644
---- a/src/contentmanager.cpp
-+++ b/src/contentmanager.cpp
-@@ -173,7 +173,7 @@ QStringList ContentManager::updateDownloadInfos(QString 
id, const QStringList &k
-         return values;
-     }
-     auto& b = mp_library->getBookById(id);
--    kiwix::Download* d;
-+    std::shared_ptr<kiwix::Download> d;
-     try {
-         d = mp_downloader->getDownload(b.getDownloadId());
-     } catch(...) {
-@@ -270,7 +270,7 @@ QString ContentManager::downloadBook(const QString &id)
-     for (auto b : booksList)
-         if (b.toStdString() == book.getId())
-             return "";
--    kiwix::Download *download;
-+    std::shared_ptr<kiwix::Download> download;
-     try {
-         std::pair<std::string, std::string> downloadDir("dir", 
downloadPath.toStdString());
-         const std::vector<std::pair<std::string, std::string>> options = { 
downloadDir };
--- 
-2.41.0
-
diff --git a/gnu/packages/pdf.scm b/gnu/packages/pdf.scm
index a595d8a0fc..4c18dad6ed 100644
--- a/gnu/packages/pdf.scm
+++ b/gnu/packages/pdf.scm
@@ -1066,13 +1066,18 @@ program capable of converting PDF into other formats.")
            qtsvg-5))
     (arguments
      (list #:tests? #f ; no tests
+           #:modules '((guix build qt-build-system)
+                       ((guix build gnu-build-system) #:prefix gnu:)
+                       (guix build utils))
            #:phases
            #~(modify-phases %standard-phases
                (replace 'configure
                  (lambda _
                    (substitute* "qpdfview.pri"
                      (("/usr") #$output))
-                   (invoke "qmake" "qpdfview.pro"))))))
+                   (invoke "qmake" "qpdfview.pro")))
+               (replace 'build (assoc-ref gnu:%standard-phases 'build))
+               (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (home-page "https://launchpad.net/qpdfview";)
     (synopsis "Tabbed document viewer")
     (description "@command{qpdfview} is a document viewer for PDF, PS and DJVU
@@ -1853,9 +1858,12 @@ Keywords: html2pdf, htmltopdf")
       (build-system cmake-build-system)
       (arguments
        (list
+        #:tests? #f ; no tests
         #:configure-flags
         #~(list (string-append "PREFIX=" #$output))
-        #:test-target "check"
+        #:modules '((guix build cmake-build-system)
+                    ((guix build gnu-build-system) #:prefix gnu:)
+                    (guix build utils))
         #:phases
         #~(modify-phases %standard-phases
             (add-after 'unpack 'patch-paths
@@ -1868,7 +1876,9 @@ Keywords: html2pdf, htmltopdf")
             (replace 'configure
               (lambda* (#:key configure-flags #:allow-other-keys)
                 (apply invoke "qmake" configure-flags)))
-            (add-after 'install 'instal-man-page
+            (replace 'build (assoc-ref gnu:%standard-phases 'build))
+            (replace 'install (assoc-ref gnu:%standard-phases 'install))
+            (add-after 'install 'install-man-page
               (lambda _
                 (install-file "resources/sioyek.1"
                               (string-append #$output "/share/man/man1")))))))
diff --git a/gnu/packages/qt.scm b/gnu/packages/qt.scm
index 567a699056..6bdcd8a7f5 100644
--- a/gnu/packages/qt.scm
+++ b/gnu/packages/qt.scm
@@ -4107,6 +4107,9 @@ instances.")
     (arguments
      (list
       #:qtbase qtbase
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (add-after 'unpack 'fix-installation-prefix
@@ -4121,6 +4124,7 @@ instances.")
           (replace 'configure
             (lambda _
               (invoke "qmake")))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
           (replace 'check
             (lambda* (#:key tests? #:allow-other-keys)
               (when tests?
@@ -5215,6 +5219,9 @@ programming paradigm.")
       (arguments
        (list #:qtbase qtbase
              #:tests? #f ;no tests
+             #:modules '((guix build qt-build-system)
+                         ((guix build gnu-build-system) #:prefix gnu:)
+                         (guix build utils))
              #:phases
              #~(modify-phases %standard-phases
                  ;; This project does not have any build rule but its demo has
@@ -5231,6 +5238,7 @@ programming paradigm.")
                  (replace 'configure
                    (lambda _
                      (invoke "qmake")))
+                 (replace 'build (assoc-ref gnu:%standard-phases 'build))
                  ;; No install rule exists.
                  (replace 'install
                    (lambda _
@@ -6093,6 +6101,9 @@ a secure way.")))
     (inputs (list dbus glib libaccounts-glib))
     (arguments
      (list #:tests? #f                  ; Figure out how to run tests
+           #:modules '((guix build qt-build-system)
+                       ((guix build gnu-build-system) #:prefix gnu:)
+                       (guix build utils))
            #:phases
            #~(modify-phases %standard-phases
                (replace 'configure
@@ -6115,7 +6126,9 @@ a secure way.")))
                            (string-append "PREFIX=" #$output)
                            (string-append "LIBDIR=" #$output "/lib")
                            (string-append "QMAKE_LFLAGS_RPATH=-Wl,-rpath,"
-                                          #$output "/lib -Wl,-rpath,")))))))
+                                          #$output "/lib -Wl,-rpath,"))))
+               (replace 'build (assoc-ref gnu:%standard-phases 'build))
+               (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (home-page "https://accounts-sso.gitlab.io/signond/index.html";)
     (synopsis "Perform user authentication over D-Bus")
     (description "This package provides a D-Bus service which performs user
@@ -6165,6 +6178,9 @@ authentication on behalf of its clients.")
     (inputs (list signond))
     (arguments
      (list #:tests? #f                  ;no tests
+           #:modules '((guix build qt-build-system)
+                       ((guix build gnu-build-system) #:prefix gnu:)
+                       (guix build utils))
            #:phases
            #~(modify-phases %standard-phases
                (replace 'configure
@@ -6176,7 +6192,9 @@ authentication on behalf of its clients.")
                            (string-append "PREFIX=" #$output)
                            (string-append "LIBDIR=" #$output "/lib")
                            (string-append "SIGNON_PLUGINS_DIR=" #$output
-                                          "/lib/signon")))))))
+                                          "/lib/signon"))))
+               (replace 'build (assoc-ref gnu:%standard-phases 'build))
+               (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (synopsis "OAuth 2 plugin for signon")
     (description
      "This plugin for the Accounts-SSO SignOn daemon handles the OAuth
diff --git a/gnu/packages/radio.scm b/gnu/packages/radio.scm
index 99de216f27..776373728b 100644
--- a/gnu/packages/radio.scm
+++ b/gnu/packages/radio.scm
@@ -2281,13 +2281,19 @@ NanoVNA vector network analyzers.")
            qtbase-5
            v4l-utils))
     (arguments
-     `(#:tests? #f  ; No test suite.
-       #:phases
-       (modify-phases %standard-phases
-         (replace 'configure
-           (lambda* (#:key outputs #:allow-other-keys)
-             (invoke "qmake"
-                     (string-append "PREFIX=" (assoc-ref outputs "out"))))))))
+     (list
+      #:tests? #f  ; No test suite.
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
+      #:phases
+      #~(modify-phases %standard-phases
+          (replace 'configure
+            (lambda* (#:key outputs #:allow-other-keys)
+              (invoke "qmake"
+                      (string-append "PREFIX=" (assoc-ref outputs "out")))))
+                (replace 'build (assoc-ref gnu:%standard-phases 'build))
+                (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (home-page "http://users.telenet.be/on4qz/qsstv/";)
     (synopsis "Program for receiving and transmitting SSTV and HAMDRM")
     (description
@@ -2643,34 +2649,40 @@ sinks and sources.")
            speexdsp
            zlib))
     (arguments
-     `(#:tests? #f
-       #:phases
-       (modify-phases %standard-phases
-         (add-after 'unpack 'fix-paths
-           (lambda* (#:key inputs outputs #:allow-other-keys)
-             (substitute* "dream.pro"
-               (("target\\.path = /usr/bin")
-                (string-append "target.path = "
-                               (assoc-ref outputs "out") "/bin"))
-               (("documentation\\.path = /usr/share/man/man1")
-                (string-append "documentation.path = "
-                               (assoc-ref outputs "out")
-                               "/share/man/man1"))
-               (("/usr/include/pulse")
-                (search-input-directory inputs "/include/pulse"))
-               (("/usr/include/sndfile\\.h")
-                (search-input-file inputs "/include/sndfile.h"))
-               (("/usr/include/opus")
-                (search-input-directory inputs "/include/opus"))
-               (("/usr/include/speex")
-                (search-input-directory inputs "/include/speex"))
-               (("/usr/include/qwt")
-                (search-input-directory inputs "/include/qwt"))
-               (("\\$\\$OUT_PWD/include/neaacdec\\.h")
-                (search-input-file inputs "/include/neaacdec.h")))))
-         (replace 'configure
-           (lambda _
-             (invoke "qmake"))))))
+     (list
+      #:tests? #f
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-after 'unpack 'fix-paths
+            (lambda* (#:key inputs outputs #:allow-other-keys)
+              (substitute* "dream.pro"
+                (("target\\.path = /usr/bin")
+                 (string-append "target.path = "
+                                (assoc-ref outputs "out") "/bin"))
+                (("documentation\\.path = /usr/share/man/man1")
+                 (string-append "documentation.path = "
+                                (assoc-ref outputs "out")
+                                "/share/man/man1"))
+                (("/usr/include/pulse")
+                 (search-input-directory inputs "/include/pulse"))
+                (("/usr/include/sndfile\\.h")
+                 (search-input-file inputs "/include/sndfile.h"))
+                (("/usr/include/opus")
+                 (search-input-directory inputs "/include/opus"))
+                (("/usr/include/speex")
+                 (search-input-directory inputs "/include/speex"))
+                (("/usr/include/qwt")
+                 (search-input-directory inputs "/include/qwt"))
+                (("\\$\\$OUT_PWD/include/neaacdec\\.h")
+                 (search-input-file inputs "/include/neaacdec.h")))))
+          (replace 'configure
+            (lambda _
+              (invoke "qmake")))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (home-page "https://sourceforge.net/projects/drm/";)
     (synopsis "Digital Radio Mondiale receiver")
     (description
@@ -3159,6 +3171,9 @@ software-defined radio receivers.")
     (arguments
      (list
       #:tests? #f  ; No test suite.
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (add-after 'unpack 'fix-paths
@@ -3183,7 +3198,9 @@ software-defined radio receivers.")
               (chdir "build")
               (invoke "qmake"
                       (string-append "PREFIX=" #$output)
-                      "../wfview.pro"))))))
+                      "../wfview.pro")))
+           (replace 'build (assoc-ref gnu:%standard-phases 'build))
+           (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (inputs
      (list eigen
            eudev
diff --git a/gnu/packages/security-token.scm b/gnu/packages/security-token.scm
index 1ce185ad07..b24eb5d3e2 100644
--- a/gnu/packages/security-token.scm
+++ b/gnu/packages/security-token.scm
@@ -815,6 +815,9 @@ an unprivileged user.")
     (arguments
      (list
       #:tests? #f                       ;no test suite
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
       #:phases
       #~(modify-phases %standard-phases
           (add-after 'unpack 'patch-paths
@@ -825,6 +828,8 @@ an unprivileged user.")
           (replace 'configure
             (lambda _
               (invoke "qmake")))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install))
           (add-after 'install 'install-desktop-resources
             (lambda _
               (let ((datadir (string-append #$output "/share")))
diff --git a/gnu/packages/tex.scm b/gnu/packages/tex.scm
index b9a3c2222b..c240878926 100644
--- a/gnu/packages/tex.scm
+++ b/gnu/packages/tex.scm
@@ -77468,19 +77468,25 @@ PDF documents.")
                 "1qnh5g8zkjpjmw2l8spcynpfgs3wpcfcla5ms2kkgvkbdlzspqqx"))))
     (build-system qt-build-system)
     (arguments
-     `(#:test-target "check"
-       #:phases
-       (modify-phases %standard-phases
-         ;; Qt has its own configuration utility.
-         (replace 'configure
-           (lambda* (#:key outputs #:allow-other-keys)
-             (let ((out (assoc-ref outputs "out")))
-               (invoke "qmake"
-                       (string-append "PREFIX=" out)
-                       (string-append "DESKTOPDIR=" out "/share/applications")
-                       (string-append "ICONDIR=" out "/share/pixmaps")
-                       (string-append "METAINFODIR=" out "/share/metainfo")
-                       "texmaker.pro")))))))
+     (list
+      #:tests? #f ; no tests
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
+      #:phases
+      #~(modify-phases %standard-phases
+          ;; Qt has its own configuration utility.
+          (replace 'configure
+            (lambda* (#:key outputs #:allow-other-keys)
+              (let ((out (assoc-ref outputs "out")))
+                (invoke "qmake"
+                        (string-append "PREFIX=" out)
+                        (string-append "DESKTOPDIR=" out "/share/applications")
+                        (string-append "ICONDIR=" out "/share/pixmaps")
+                        (string-append "METAINFODIR=" out "/share/metainfo")
+                        "texmaker.pro"))))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (inputs
      (list poppler-qt5 qtbase-5 qtwayland-5 qtscript-5 zlib))
     (native-inputs
diff --git a/gnu/packages/video.scm b/gnu/packages/video.scm
index 745f213233..6cd567b357 100644
--- a/gnu/packages/video.scm
+++ b/gnu/packages/video.scm
@@ -2839,9 +2839,14 @@ projects while introducing many more.")
      (list #:tests? #false              ; no tests
            #:make-flags #~(list (string-append "PREFIX=" #$output)
                                 (string-append "CC=" #+(cc-for-target)))
+           #:modules '((guix build qt-build-system)
+                       ((guix build gnu-build-system) #:prefix gnu:)
+                       (guix build utils))
            #:phases
            #~(modify-phases %standard-phases
                (delete 'configure)
+               (replace 'build (assoc-ref gnu:%standard-phases 'build))
+               (replace 'install (assoc-ref gnu:%standard-phases 'install))
                (add-after 'install 'wrap-executable
                  (lambda* (#:key inputs outputs #:allow-other-keys)
                    (let* ((out (assoc-ref outputs "out"))
diff --git a/gnu/packages/web.scm b/gnu/packages/web.scm
index 85502e2417..bb774f8785 100644
--- a/gnu/packages/web.scm
+++ b/gnu/packages/web.scm
@@ -9566,7 +9566,7 @@ of Geminispace, but it defaults to a specific domain.")
 (define-public libzim
   (package
     (name "libzim")
-    (version "8.2.1")
+    (version "9.3.0")
     (source (origin
               (method git-fetch)
               (uri (git-reference
@@ -9574,7 +9574,7 @@ of Geminispace, but it defaults to a specific domain.")
                     (commit version)))
               (sha256
                (base32
-                "1g735aqw0vlxqgyjv02lvq24dr5shydp4y8mqianf8720s5fs73f"))
+                "1il1vc1hs954s3vnwhr337165dxbykvrldrvbilp5jxbkmwqb60d"))
               (file-name (git-file-name name version))))
     (build-system meson-build-system)
     (arguments
@@ -9600,7 +9600,7 @@ for ZIM files.")
 (define-public kiwix-lib
   (package
     (name "kiwix-lib")
-    (version "13.0.0")
+    (version "14.0.0")
     (home-page "https://github.com/kiwix/kiwix-lib/";)
     (source (origin
               (method git-fetch)
@@ -9609,7 +9609,7 @@ for ZIM files.")
                     (commit version)))
               (sha256
                (base32
-                "0mvlppbj0mqn4ka3cfaaj1pvn062cxbgz01c0nq04x0mzq1xwh5w"))
+                "099arjsx1wgz5jhvzn49859wh0v8n3ya33kmnqaw69h55mjvgza0"))
               (file-name (git-file-name name version))))
     (build-system meson-build-system)
     (arguments
@@ -9645,7 +9645,7 @@ It contains the code shared by all Kiwix ports.")
 (define-public kiwix-desktop
   (package
     (name "kiwix-desktop")
-    (version "2.3.1")
+    (version "2.4.1")
     (source (origin
               (method url-fetch)
               (uri (string-append
@@ -9654,18 +9654,23 @@ It contains the code shared by all Kiwix ports.")
                     ".tar.gz"))
               (sha256
                (base32
-                "0hlk05gcb3fmnxhwj6gan51v98rdq3iv2lklwbpmm1bazmz8i7br"))
-              (patches (search-patches "kiwix-desktop-newer-libkiwix.patch"))))
+                "1vkmk9j2jii7ri4lcayr0dr5b2w3dc24lyqmm3g4234834b1f4wl"))))
     (build-system qt-build-system)
     (arguments
-     `(#:test-target "check"
-       #:phases
-       (modify-phases %standard-phases
-         (replace 'configure
-           (lambda* (#:key outputs #:allow-other-keys)
-             (invoke "qmake"
-                     (string-append "PREFIX="
-                                    (assoc-ref outputs "out"))))))))
+     (list
+      #:tests? #f ; no tests
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
+      #:phases
+      #~(modify-phases %standard-phases
+          (replace 'configure
+            (lambda* (#:key outputs #:allow-other-keys)
+              (invoke "qmake"
+                      (string-append "PREFIX="
+                                     (assoc-ref outputs "out")))))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'install (assoc-ref gnu:%standard-phases 'install)))))
     (inputs
      (list bash-minimal
            curl
@@ -9694,14 +9699,14 @@ offline (such as Wikipedia), without any access to 
Internet.")
 (define-public kiwix-tools
   (package
     (name "kiwix-tools")
-    (version "3.5.0")
+    (version "3.7.0")
     (source (origin
               (method url-fetch)
               (uri (string-append "https://download.kiwix.org/release/";
                                   "kiwix-tools/kiwix-tools-" version 
".tar.xz"))
               (sha256
                (base32
-                "0q6b7viy1jr212q0glqid2hqxnsd2mxsx5gzcalkc4gb0bzgj32d"))))
+                "032lzzgn3hicai4lx701cs6h731cs29x1h59j9gggcgrp1n4wxks"))))
     (build-system meson-build-system)
     (inputs
      (list curl

Reply via email to
diff --git a/gnu/packages/emulators.scm b/gnu/packages/emulators.scm
index b36ba153a5..37c9bfc84c 100644
--- a/gnu/packages/emulators.scm
+++ b/gnu/packages/emulators.scm
@@ -705,39 +705,44 @@ emulate a serial nullmodem over TCP/IP.")
                 "1fal7a8y5g0rqqjrk795jh1l50ihz01ppjnrfjrk9vkjbd59szbp"))))
     (build-system qt-build-system)
     (arguments
-     '(#:phases
-       (modify-phases %standard-phases
-         (replace 'configure
-           (lambda* (#:key outputs #:allow-other-keys)
-             (invoke "qmake"
-                     (string-append "PREFIX=" (assoc-ref outputs "out"))
-                     "qtmips.pro")))
-         (replace 'check
-           (lambda* (#:key tests? #:allow-other-keys)
-             (substitute* "tests/test.sh"
-               (("qtchooser.*") ""))
-             (substitute* '("tests/cpu_trap/test.sh"
-                            "tests/registers/test.sh")
-               (("sub-qtmips_cli") "qtmips_cli"))
-             (if tests?
-               (invoke "tests/run-all.sh")
-               #t)))
-         (replace 'install
-           ;; There is no install target.
-           (lambda* (#:key outputs #:allow-other-keys)
-             (let* ((out (assoc-ref outputs "out"))
-                    (bin (string-append out "/bin"))
-                    (apps (string-append out "/share/applications"))
-                    (icons (string-append out "/share/icons/hicolor")))
-               (install-file "qtmips_gui/qtmips_gui" bin)
-               (install-file "qtmips_cli/qtmips_cli" bin)
-               (install-file "data/qtmips.desktop" apps)
-               (install-file "data/icons/qtmips_gui.svg"
-                             (string-append icons "/scalable/apps"))
-               (install-file "data/icons/qtmips_gui.png"
-                             (string-append icons "/48x48/apps"))
-               #t))))
-       #:tests? #f))    ; test suite wants mips toolchain
+     (list
+      #:modules '((guix build qt-build-system)
+                  ((guix build gnu-build-system) #:prefix gnu:)
+                  (guix build utils))
+      #:phases
+      #~(modify-phases %standard-phases
+          (replace 'configure
+            (lambda* (#:key outputs #:allow-other-keys)
+              (invoke "qmake"
+                      (string-append "PREFIX=" (assoc-ref outputs "out"))
+                      "qtmips.pro")))
+          (replace 'build (assoc-ref gnu:%standard-phases 'build))
+          (replace 'check
+            (lambda* (#:key tests? #:allow-other-keys)
+              (substitute* "tests/test.sh"
+                (("qtchooser.*") ""))
+              (substitute* '("tests/cpu_trap/test.sh"
+                             "tests/registers/test.sh")
+                (("sub-qtmips_cli") "qtmips_cli"))
+              (if tests?
+                (invoke "tests/run-all.sh")
+                #t)))
+          (replace 'install
+            ;; There is no install target.
+            (lambda* (#:key outputs #:allow-other-keys)
+              (let* ((out (assoc-ref outputs "out"))
+                     (bin (string-append out "/bin"))
+                     (apps (string-append out "/share/applications"))
+                     (icons (string-append out "/share/icons/hicolor")))
+                (install-file "qtmips_gui/qtmips_gui" bin)
+                (install-file "qtmips_cli/qtmips_cli" bin)
+                (install-file "data/qtmips.desktop" apps)
+                (install-file "data/icons/qtmips_gui.svg"
+                              (string-append icons "/scalable/apps"))
+                (install-file "data/icons/qtmips_gui.png"
+                              (string-append icons "/48x48/apps"))
+                #t))))
+        #:tests? #f))    ; test suite wants mips toolchain
     (inputs
      (list elfutils qtbase-5 qtwayland-5))
     (home-page "https://github.com/cvut/QtMips";)